@@ -19,6 +19,8 @@ class Audalign:
     MATCH_TIME = "match_time"
     OFFSET_SAMPLES = "offset_samples"
     OFFSET_SECS = "offset_seconds"
+    LOCALITY = "locality"
+    LOCALITY_SECS = "locality_seconds"
 
     def __init__(
         self,
@@ -406,13 +408,14 @@ class Audalign:
         return [file_name, hashes]
 
     def recognize(
-        self, file_path: str, filter_matches: int = 1, *args, **kwargs
+        self, file_path: str, filter_matches: int = 1, locality=None, *args, **kwargs
     ) -> None:
         """
         Recognizes given file against already fingerprinted files
 
         Offset describes duration that the recognized file aligns after the target file
         Does not recognize against files with same name and extention
+        Locality option used to only return match results within certain second range
 
         Parameters
         ----------
@@ -420,6 +423,8 @@ class Audalign:
             file path of target file to recognize
         filter_matches : int
             filters all matches lower than given argument, 1 is recommended
+        locality : float
+            filters matches to only count within locality. In seconds
 
         Returns
         -------
@@ -430,11 +435,7 @@ class Audalign:
 
             None : if no match
         """
-        # Locality option used to only return match results within certain second range
 
-        # locality : int
-        #     filters results by locality in seconds
-        locality = None
         return recognize.recognize(
             self, file_path, filter_matches, locality, *args, **kwargs
         )
@@ -598,6 +599,7 @@ class Audalign:
         use_fingerprints: bool = True,
         alternate_strength_stat: str = None,
         filter_matches: int = 1,
+        locality: float = None,
         volume_threshold: float = 216,
         volume_floor: float = 10.0,
         vert_scaling: float = 1.0,
@@ -617,6 +619,7 @@ class Audalign:
             use_fingerprints (bool, optional): Fingerprints if True, visual recognition if False. Defaults to True.
             alternate_strength_stat (str, optional): confidence for fingerprints, ssim for visual, mse or count also work for visual. Defaults to None.
             filter_matches (int, optional): filter matches level for fingerprinting. Defaults to 1.
+            locality (float, optional): In seconds for fingerprints, only matches files within given window sizes
             volume_threshold (float, optional): volume threshold for visual recognition. Defaults to 216.
             volume_floor (float): ignores volume levels below floow.
             vert_scaling (float): scales vertically to speed up calculations. Smaller numbers have smaller images.
@@ -656,7 +659,9 @@ class Audalign:
                     self.fingerprint_file(target_file)
                 self.fingerprint_directory(directory_path)
 
-                alignment = self.recognize(target_file, filter_matches=filter_matches)
+                alignment = self.recognize(
+                    target_file, filter_matches=filter_matches, locality=locality
+                )
 
             else:
                 alignment = self.visrecognize_directory(
@@ -727,6 +732,7 @@ class Audalign:
         destination_path: str = None,
         write_extension: str = None,
         filter_matches: int = 1,
+        locality: float = None,
     ):
         """
         Finds matches and relative offsets for all files in directory_path, aligns them, and writes them to destination_path
@@ -742,6 +748,9 @@ class Audalign:
         write_extension : str
             if given, writes all alignments with given extension (ex. ".wav" or "wav")
 
+        locality : float
+            Only recognizes against fingerprints in given width. In seconds
+
         Returns
         -------
         files_shifts : dict{float}
@@ -771,7 +780,9 @@ class Audalign:
             for file_path, _ in filehandler.find_files(directory_path):
                 name = os.path.basename(file_path)
                 if name in self.file_names:
-                    alignment = self.recognize(file_path, filter_matches=filter_matches)
+                    alignment = self.recognize(
+                        file_path, filter_matches=filter_matches, locality=locality
+                    )
                     file_names_and_paths[name] = file_path
                     total_alignment[name] = alignment
 
